@@ -2,6 +2,8 @@ from functools import wraps
 
 from flask import g, jsonify
 
+from ForMark.ForLog import ForLog
+
 
 def get_params(params=None):
     def wrapper(func):
@@ -12,7 +14,7 @@ def get_params(params=None):
                     return jsonify(success=False, msg='缺少必填参数', code='10001')
                 for item in params.items():
                     key = g.params.get(item[0], None)
-                    print("参数",key)
+                    ForLog.show("参数",key)
                     if key is None:
                         return jsonify(success=False, msg=item[1], code='10001')
                     g.setdefault(item[0], key)
